---
title: <span class="badge builder"></span> ControlsOptions
---
# <span class="badge builder"></span> ControlsOptions

## Constructor

```python
ControlsOptions()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> geomap.ControlsOptions
```

### <span class="badge object-method"></span> mouse_wheel_zoom

let the mouse wheel zoom

```python
def mouse_wheel_zoom(mouse_wheel_zoom: bool) -> typing.Self
```

### <span class="badge object-method"></span> show_attribution

Lower right

```python
def show_attribution(show_attribution: bool) -> typing.Self
```

### <span class="badge object-method"></span> show_debug

Show debug

```python
def show_debug(show_debug: bool) -> typing.Self
```

### <span class="badge object-method"></span> show_measure

Show measure

```python
def show_measure(show_measure: bool) -> typing.Self
```

### <span class="badge object-method"></span> show_scale

Scale options

```python
def show_scale(show_scale: bool) -> typing.Self
```

### <span class="badge object-method"></span> show_zoom

Zoom (upper left)

```python
def show_zoom(show_zoom: bool) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [ControlsOptions](./object-ControlsOptions.md)
